<!DOCTYPE html>

<!--
Copyright 2017-2018 Purism SPC
https://source.puri.sm/liberty/psh_middleware
SPDX-License-Identifier: AGPL-3.0
-->

<html lang="en">
<head>
    <title>JavaScript license information</title>
    <link rel="icon" sizes="960x960" href="{% static 'favicon.png' %}"/>
    <meta name="application-name" content="{{ site_title }}"/>
    <meta charset="UTF-8"/>
</head>

<body>

<h1>
    JavaScript license information
</h1>

<p>
    No licenses. <em>Keel - PSH Middleware</em> does not require JavaScript, minified or otherwise, at this time.
</p>

<table id="jslicense-labels1">
</table>

<p>
    Return to <a href="{% url 'home' %}">{{ site_title }}</a>
</p>

</body>
</html>
