from django.contrib import admin
from django.contrib.auth.admin import UserAdmin as BaseUserAdmin

from .models import User


#
# Declare admin models
#

class UserAdmin(BaseUserAdmin):
    pass


#
# Register admin models
#

admin.site.register(User, UserAdmin)
