# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-09 23:34
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('limitmonitor', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='limit',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='credit',
            name='external',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to='limitmonitor.ExternalCredit'),
        ),
        migrations.AddField(
            model_name='credit',
            name='limit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='limitmonitor.Limit'),
        ),
    ]
