{% extends "base.html" %}
{% load i18n %}
{% load crispy_forms_tags %}

{% block title %}{% trans 'Closed' %}{% endblock %}
{% block header %}{% trans 'Closed' %}{% endblock %}
{% block byline %}{% trans 'Registration has been disabled on this instance' %}{% endblock %}

{% block content %}
{% endblock %}

