# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-12-08 13:27
from __future__ import unicode_literals

import choicesenum.django.fields
from django.db import migrations

import limitmonitor.models


class Migration(migrations.Migration):
    dependencies = [
        ('limitmonitor', '0002_auto_20171009_2334'),
    ]

    operations = [
        migrations.AlterField(
            model_name='externalbundle',
            name='parser',
            field=choicesenum.django.fields.EnumIntegerField(default=limitmonitor.models.Legacy(0),
                                                             enum=limitmonitor.models.Legacy),
        ),
        migrations.AlterField(
            model_name='externalbundle',
            name='service',
            field=choicesenum.django.fields.EnumIntegerField(default=limitmonitor.models.Legacy(0),
                                                             enum=limitmonitor.models.Legacy),
        ),
        migrations.AlterField(
            model_name='externalcredit',
            name='parser',
            field=choicesenum.django.fields.EnumIntegerField(default=limitmonitor.models.Legacy(0),
                                                             enum=limitmonitor.models.Legacy),
        ),
        migrations.AlterField(
            model_name='limit',
            name='service',
            field=choicesenum.django.fields.EnumIntegerField(default=limitmonitor.models.Legacy(0),
                                                             enum=limitmonitor.models.Legacy),
        ),
    ]
