# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-01-09 11:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('limitmonitor', '0003_auto_20171208_1327'),
    ]

    operations = [
        migrations.AlterField(
            model_name='externalbundle',
            name='service',
            field=models.IntegerField(choices=[(0, 'Undefined')], default=0),
        ),
        migrations.AlterField(
            model_name='limit',
            name='service',
            field=models.IntegerField(choices=[(0, 'Undefined')], default=0),
        ),
    ]
