# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-09 23:34
from __future__ import unicode_literals

from django.db import migrations, models
import ldapdb.models.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='LdapGroup',
            fields=[
                ('dn', models.CharField(max_length=200, primary_key=False, serialize=False)),
                ('cn', ldapdb.models.fields.CharField(db_column='cn', max_length=200, primary_key=True, serialize=False)),
                ('description', ldapdb.models.fields.CharField(db_column='description', max_length=200)),
                ('members', ldapdb.models.fields.ListField(db_column='member')),
            ],
            options={
                'verbose_name': 'LDAP group',
                'verbose_name_plural': 'LDAP groups',
            },
        ),
        migrations.CreateModel(
            name='LdapPerson',
            fields=[
                ('dn', models.CharField(max_length=200, primary_key=False, serialize=False)),
                ('uid', ldapdb.models.fields.CharField(db_column='uid', max_length=200, primary_key=True, serialize=False)),
                ('cn', ldapdb.models.fields.CharField(db_column='cn', max_length=200)),
                ('description', ldapdb.models.fields.CharField(db_column='description', max_length=200)),
                ('sn', ldapdb.models.fields.CharField(db_column='sn', max_length=200)),
            ],
            options={
                'verbose_name': 'LDAP person',
                'verbose_name_plural': 'LDAP people',
            },
        ),
    ]
