# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-02-15 11:33
from __future__ import unicode_literals

import ldapdb.models.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('ldapregister', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='ldapperson',
            name='mail',
            # field=ldapdb.models.fields.CharField(db_column='mail', default='none', max_length=200),
            field=ldapdb.models.fields.CharField(db_column='mail', max_length=200),
            preserve_default=False,
        ),
    ]
