# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-12-08 13:27
from __future__ import unicode_literals

from django.db import migrations, models

import purist.custom


class Migration(migrations.Migration):
    dependencies = [
        ('purist', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='username',
            field=models.CharField(error_messages={'unique': 'A user with that username already exists.'},
                                   help_text='Required. Start with a letter, followed by letters and numbers.',
                                   max_length=150, unique=True, validators=[purist.custom.UsernameValidator()],
                                   verbose_name='username'),
        ),
    ]
