# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-09 23:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Credit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('time_credit', models.DecimalField(decimal_places=2, default=0, max_digits=6)),
                ('volume_credit', models.DecimalField(decimal_places=2, default=0, max_digits=6)),
                ('old_expiry_date', models.DateTimeField(blank=True, default=None, null=True)),
                ('old_time_total', models.DecimalField(blank=True, decimal_places=2, default=None, max_digits=6, null=True)),
                ('old_volume_total', models.DecimalField(blank=True, decimal_places=2, default=None, max_digits=6, null=True)),
                ('new_expiry_date', models.DateTimeField(blank=True, default=None, null=True)),
                ('new_time_total', models.DecimalField(blank=True, decimal_places=2, default=None, max_digits=6, null=True)),
                ('new_volume_total', models.DecimalField(blank=True, decimal_places=2, default=None, max_digits=6, null=True)),
                ('created_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.CreateModel(
            name='ExternalBundle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('parser', models.CharField(choices=[('WOO1', 'WooCommerce v1'), ('WOOSUB1', 'WooCommerce Subscription v1')], max_length=30)),
                ('external_key', models.CharField(max_length=30)),
                ('service', models.CharField(choices=[('TUNNEL', 'Tunnel'), ('COMMUNICATION', 'Communication')], max_length=30)),
                ('time_credit', models.DecimalField(decimal_places=2, default=0, max_digits=6)),
                ('volume_credit', models.DecimalField(decimal_places=2, default=0, max_digits=6)),
                ('created_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.CreateModel(
            name='ExternalCredit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('parser', models.CharField(choices=[('WOO1', 'WooCommerce v1'), ('WOOSUB1', 'WooCommerce Subscription v1')], max_length=30)),
                ('external_key', models.CharField(max_length=30)),
                ('label', models.CharField(max_length=30)),
                ('bundle_key', models.CharField(max_length=30)),
                ('bundle_label', models.CharField(max_length=30)),
                ('quantity', models.DecimalField(decimal_places=2, default=1, max_digits=6)),
                ('account_name', models.CharField(default='', max_length=30)),
                ('additional_data', models.TextField(default='')),
                ('error_message', models.TextField(default='')),
                ('is_converted', models.BooleanField(default=False)),
                ('created_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.CreateModel(
            name='Limit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('service', models.CharField(choices=[('TUNNEL', 'Tunnel'), ('COMMUNICATION', 'Communication')], max_length=30)),
                ('renewal_date', models.DateTimeField(blank=True, default=None, null=True)),
                ('expiry_date', models.DateTimeField(blank=True, default=None, null=True)),
                ('volume_total', models.DecimalField(decimal_places=2, default=0, max_digits=6)),
                ('time_total', models.DecimalField(decimal_places=2, default=0, max_digits=6)),
                ('is_active', models.BooleanField(default=False)),
                ('created_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]
